import sinon from 'sinon';
import { Lang } from '../lib/lang-mongoose';


export const languages = [
    { lang: 'ca', displayName: 'Català' },
    { lang: 'es', displayName: 'Espanyol' },
    { lang: 'en', displayName: 'Anglès' },
];

const getLanguages = () => Promise.resolve(languages);


export const stubLangFind = () => {
    const find = {};

    beforeEach(() => {
        find.stub = sinon.stub(Lang, 'find', () => ({
            exec: getLanguages,
            sort: () => ({
                exec: getLanguages,
            }),
        }));
    });

    afterEach(() => {
        find.stub.restore();
    });

    return find;
};

export const stubLangFindErr = () => {
    const find = {};

    beforeEach(() => {
        find.stub = sinon.stub(Lang, 'find', () => ({
            exec: () => Promise.reject('Database error'),
        }));
    });

    afterEach(() => {
        find.stub.restore();
    });

    return find;
};


export const stubLangfindOneAndUpdate = () => {
    const findOneAndUpdate = {};

    beforeEach(() => {
        findOneAndUpdate.stub = sinon.stub(Lang, 'findOneAndUpdate', () => ({
            exec: () => { },
        }));
    });

    afterEach(() => {
        findOneAndUpdate.stub.restore();
    });

    return findOneAndUpdate;
};
